# miltertest

This is a pure Python module implementing the milter protocol, based on
Chris Siebenmann's work in [python-milter-tools](https://github.com/siebenmann/python-milter-tools).

The main goal is to provide an acceptable interface for acting as
an MTA to test milter implementations; it may also be usable for
implementing milters, but there are better options for that.
